"use client";

import dynamic from "next/dynamic";
import {Suspense, useMemo} from "react";
import {Skeleton} from "../ui/skeleton";
import Image from "next/image";
import {urlImage} from "@/lib/urlIMG";

interface Props {
  mapsData: any;
  mapsDetails: any;
  gmaps: string;
}

export default function Map({mapsData, mapsDetails, gmaps}: Props) {
  const Maps = useMemo(
    () =>
      dynamic(() => import("@/components/map-widget"), {
        loading: () => <Skeleton className="w-full h-[250px] lg:h-[800px]" />,
        ssr: false,
      }),
    []
  );

  const zoom = 15;

  return (
    <article
      id="location"
      className="w-full h-full lg:min-h-fit py-5 px-5 xl:px-0 relative space-y-10 scroll-mt-10 lg:scroll-mt-14"
    >
      <hr className="w-full border-main lg:hidden" />
      <h2 className="lg:hidden text-center text-main">Location</h2>

      <div className="w-full h-[250px] lg:h-[800px]">
        <Suspense
          fallback={<Skeleton className="w-full h-[250px] lg:h-[800px]" />}
        >
          <Maps position={[mapsData.location_lat, mapsData.location_long]} zoom={zoom} title={location} />
        </Suspense>
      </div>

      <div className="block xl:absolute top-1/2 left-3/4 transform xl:-translate-x-1/2 xl:-translate-y-1/2 lg:w-[400px] w-full lg:mx-auto">
        <div className="flex flex-col xl:gap-2 gap-5 bg-transparent xl:bg-white md:p-5">
          <div className="flex flex-row gap-2 items-center justify-start">
            <Image
              src="/svg/PinPoint.svg"
              alt="PinPoint"
              width={30}
              height={30}
              className="object-cover w-[30px] h-[30px]"
            />
            <span className="text-sm md:text-base tracking-wide text-main">{mapsData.location_address}</span>
          </div>
          {mapsDetails.map((item: any, index: number) => (
            <div
              key={index}
              className="flex flex-row gap-2 items-center justify-start"
            >
              <Image
                src={item.icon}
                alt={item.name}
                width={30}
                height={30}
                className="object-cover"
              />
              <span className="text-sm md:text-base tracking-wide text-main">{item.name}</span>
            </div>
          ))}
          <a
            href={gmaps}
            target="_blank"
            className="w-full bg-main text-white font-semibold text-center py-2"
          >
            Get directions
          </a>
        </div>
      </div>
    </article>
  );
}
